@@ -304,7 +304,7 @@ class XenobladeXContext(CommonContext):
         super().__init__(server_address, password)
         self.ready_callback = ready_callback
         self.error_callback = error_callback
-        self.username = slot_name
+        self.username = urllib.parse.urlparse(server_address).username
         self.http_server = XenobladeXHttpServer(('::', 45872), debug=debug)
         if self.ready_callback:
             from kivy.clock import Clock
@@ -528,7 +528,7 @@ async def xenoblade_x_sync_task(ctx: XenobladeXContext) -> None:
         await asyncio.sleep(0.5)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None, debug: bool = False):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None, debug: bool = False):
     """
     Launch the client
     """
@@ -576,9 +576,9 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None, debug: bool = False):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None, debug: bool = False):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback, debug)
+    launch(server_address, password, ready_callback, error_callback, debug)
 
 
 if __name__ == '__main__':
